#!/bin/sh
#
# POPfile Installation script for Mac OS X 10.5.x (Leopard)
#
popfile="1.0.0"
SQLite2="0.33"
DBI="1.604"
Tagset="3.20"
Template="2.9"
Base64="3.07"
TimeDate="1.16"
#
PFPATH="Library/POPfile"
#
# Copyright (c) 2008 Rick Parsons.
#
# This software is published Open Source Freeware. You are free to use the
# programs either in full or part without charge. I would ask however that
# this notice is included with any extract or onward distribution.
#
# No charge may be made for the use of this code, however there is no
# objection to including modest extracts (with acknowledgement) in otherwise
# commercial software.
#
# No warranty is given or implied by the use of the software which you do at
# your own risk. No compensation can be considered regarding damage to data,
# computers or any thing else arising as a result of using these programs.
#
# Yes, this could all be made more compact using functions but I didn't have
#	the energy. It could probably also be made to work out the version
#	numbers for itself.
#
# Check that all the required packages are available
#
if [ ! -f popfile-${popfile}.zip ]; then
	echo "popfile-${popfile}.zip not found."
	exit 12
fi
#
if [ ! -f DBD-SQLite2-${SQLite2}.tar.gz ]; then
	echo "DBD-SQLite2-${SQLite2}.tar.gz not found."
	exit 12
fi
#
if [ ! -f DBI-${DBI}.tar.gz ]; then
	echo "DBI-${DBI}.tar.gz not found."
	exit 12
fi
#
if [ ! -f HTML-Tagset-${Tagset}.tar.gz ]; then
	echo "HTML-Tagset-${Tagset}.tar.gz not found."
	exit 12
fi
#
if [ ! -f HTML-Template-${Template}.tar.gz ]; then
	echo "HTML-Template-${Template}.tar.gz not found."
	exit 12
fi
#
if [ ! -f MIME-Base64-${Base64}.tar.gz ]; then
	echo "MIME-Base64-${Base64}.tar.gz not found."
	exit 12
fi
#
if [ ! -f TimeDate-${TimeDate}.tar.gz ]; then
	echo "TimeDate-${TimeDate}.tar.gz not found."
	exit 12
fi
#
# Check that the Xcode developer kit has been installed. Not a perfect test.
#
if [ ! -x /usr/bin/gcc ]; then
	echo "Cannot find the Xcode developer kit, please install it first."
	exit 12
fi
#
# See if a previous version of POPfile is already installed,
#	if so, stop it first.
# This only checks versions installed by the same method.
#
if [ -x /Library/StartupItems/POPfile/POPfile ]; then
	sudo /Library/StartupItems/POPfile/POPfile stop
fi
#
# Note where it will be installed as a full path name
#
POPINST=$HOME/$PFPATH
mkdir -p $POPINST
#
# Install the POPfile main package
#
unzip -o popfile-${popfile}.zip -d $POPINST
#
# Install the AutoStart files. These come with their absolute path and
#	all owners, groups & perfmissions preset. This was built using the
#	command
# tar czPf POPfile-AutoStart.tar.gz \
#	/Library/StartupItems/POPfile/StartupParameters.plist \
#	/Library/StartupItems/POPfile/Resources \
#	/Library/StartupItems/POPfile/POPfile
#
sudo tar xzpPf POPfile-AutoStart.tar.gz
#
# Subsequently the install package itself was built using the command
# zip popinst Install.sh POPfile-AutoStart.tar.gz popfile.htm
#
# Tell it where POPfile is installed. The start-up script uses this to
#	locate where the package is using
#	PFPATH=`cat /Library/StartupItems/POPfile/POPfile.txt`
#
echo $POPINST >POPfile.txt
sudo mv POPfile.txt /Library/StartupItems/POPfile/POPfile.txt
#
# Extract, compile and install the Perl Modules, removing temporary files
#	each time
#
tar xzf DBD-SQLite2-${SQLite2}.tar.gz
cd DBD-SQLite2-${SQLite2}
perl Makefile.PL
make
sudo make install
cd ..
rm -rf DBD-SQLite2-${SQLite2}
#
tar xzf DBI-${DBI}.tar.gz
cd DBI-${DBI}
perl Makefile.PL
make
sudo make install
cd ..
rm -rf DBI-${DBI}
#
tar xzf HTML-Tagset-${Tagset}.tar.gz
cd HTML-Tagset-${Tagset}
perl Makefile.PL
make
sudo make install
cd ..
rm -rf HTML-Tagset-${Tagset}
#
tar xzf HTML-Template-${Template}.tar.gz
cd HTML-Template-${Template}
perl Makefile.PL
make
sudo make install
cd ..
rm -rf HTML-Template-${Template}
#
tar xzf MIME-Base64-${Base64}.tar.gz
cd MIME-Base64-${Base64}
perl Makefile.PL
make
sudo make install
cd ..
rm -rf MIME-Base64-${Base64}
#
tar xzf TimeDate-${TimeDate}.tar.gz
cd TimeDate-${TimeDate}
perl Makefile.PL
make
sudo make install
cd ..
rm -rf TimeDate-${TimeDate}
#
# Start the package
#
sudo /Library/StartupItems/POPfile/POPfile start
#
echo "Installation complete."
#
exit 0
